@@ -2,5 +2,5 @@ all_equals<-function(x,y){
 	if(class(x)!=class(y)){
 		stop("Different types")
 	}
-	all(identical(x,y))
+	all(identical(round(x,16),round(y,16)))
 }
\ No newline at end of file
